.. _meetups:

Meetups
=======

Join our discussions, tutorials, workshops and sprints!

Most of our meetups take place on Discord. You can join sktime's community
server `here <https://discord.com/invite/gqSab2K>`_.

.. raw:: html

    <iframe src="https://calendar.google.com/calendar/embed?height=600&wkst=2&bgcolor=%23ffffff&ctz=UTC&src=c2t0aW1lLnRvb2xib3hAZ21haWwuY29t&color=%23039BE5&showCalendars=0&showTabs=1&showPrint=0&showDate=1&showNav=1&showTitle=1&title=sktime%20community%20calendar&mode=AGENDA" style="border-width:0" width="600" height="600" frameborder="0" scrolling="no"></iframe>
